
		Low-Energy X-ray Interaction Coefficients:
		Photoabsorption, Scattering, and Reflection
		E = 10-30,000 eV, Z = 1-92
        from:
            
        Detailed Tabulation of Atomic Form Factors,
        Photoelectric Absorption and Scattering Cross Section,
        and Mass Attenuation Coefficients for Z = 1-92 from E = 1-10 eV to E = 0.4-1.0 MeV
        C.T. Chantler,1 K. Olsen, R.A. Dragoset, J. Chang, A.R. Kishore, S.A. Kotochigova, and D.S. Zucker
        NIST, Physical Measurement Laboratory


    These files were used to generate the tables published in reference above.
    The files contain three columns of data: Energy(eV), f_1, f_2,
    where f_1 and f_2 are the atomic (forward) scattering factors.
    If either one was not available over the full range, it was filled with zeros.